Package com.draftable.api.client
Class Comparisons.UnknownErrorException
- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- java.lang.RuntimeException
-
- com.draftable.api.client.Comparisons.UnknownErrorException
-
- All Implemented Interfaces:
Serializable
- Enclosing class:
- Comparisons
public static class Comparisons.UnknownErrorException extends RuntimeException
Thrown when an unknown error occurs while making a request. This should never occur, but the library guarantees that any extraneous exceptions are wrapped in anComparisons.UnknownErrorException.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description UnknownErrorException(Throwable error)
-
Method Summary
-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
UnknownErrorException
public UnknownErrorException(@Nonnull Throwable error)
-
-