Package com.draftable.api.client
-
Class Summary Class Description Comparison Represents a comparison that has been created.Comparison.Side Represents a file passed as the left or right side of a comparison.Comparisons Client for the `comparisons` endpoint in the Draftable Comparison API.Comparisons.Side Represents a file passed in as one side of a comparison.KnownURLs -
Exception Summary Exception Description Comparisons.BadRequestException Thrown when aComparisons.createComparison(com.draftable.api.client.Comparisons.Side, com.draftable.api.client.Comparisons.Side)request is made with bad parameters.Comparisons.ComparisonNotFoundException Thrown when the aComparisons.getComparison(String)orComparisons.deleteComparison(String)request is made for a non-existent comparison.Comparisons.InvalidAuthenticationException Thrown when a request is made, but the provided auth token is invalid.Comparisons.UnknownErrorException Thrown when an unknown error occurs while making a request.