Constant Field Values
Contents
com.draftable.*
-
com.draftable.api.client.Comparisons Modifier and Type Constant Field Value public static final StringdefaultApiBase"https://api.draftable.com/v1" -
com.draftable.api.client.KnownURLs Modifier and Type Constant Field Value public static final StringCloudBaseURL"https://api.draftable.com/v1"