C D G I K P S T U
All Classes All Packages
All Classes All Packages
All Classes All Packages
C
- close() - Method in class com.draftable.api.client.Comparisons
-
Closes any open inner HTTP clients, and ends any async event loops.
- CloudBaseURL - Static variable in class com.draftable.api.client.KnownURLs
- com.draftable.api.client - package com.draftable.api.client
- Comparison - Class in com.draftable.api.client
-
Represents a comparison that has been created.
- Comparison(String, Comparison.Side, Comparison.Side, boolean, Instant, Instant, boolean, Instant, Boolean, String) - Constructor for class com.draftable.api.client.Comparison
-
Creates a representation of a comparison that has been created.
- Comparison.Side - Class in com.draftable.api.client
-
Represents a file passed as the left or right side of a comparison.
- Comparisons - Class in com.draftable.api.client
-
Client for the `comparisons` endpoint in the Draftable Comparison API.
- Comparisons(String, String) - Constructor for class com.draftable.api.client.Comparisons
-
Constructs a
Comparisonsinstance for the given credentials, which can then be used to make API requests. - Comparisons(String, String, String) - Constructor for class com.draftable.api.client.Comparisons
-
Constructs a
Comparisonsinstance for the given credentials and apiBaseUrl, which can then be used to make API requests. - Comparisons.BadRequestException - Exception in com.draftable.api.client
-
Thrown when a
Comparisons.createComparison(com.draftable.api.client.Comparisons.Side, com.draftable.api.client.Comparisons.Side)request is made with bad parameters. - Comparisons.ComparisonNotFoundException - Exception in com.draftable.api.client
-
Thrown when the a
Comparisons.getComparison(String)orComparisons.deleteComparison(String)request is made for a non-existent comparison. - Comparisons.InvalidAuthenticationException - Exception in com.draftable.api.client
-
Thrown when a request is made, but the provided auth token is invalid.
- Comparisons.Side - Class in com.draftable.api.client
-
Represents a file passed in as one side of a comparison.
- Comparisons.UnknownErrorException - Exception in com.draftable.api.client
-
Thrown when an unknown error occurs while making a request.
- create(byte[], String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by as a byte array. - create(byte[], String, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by as a byte array. - create(File) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a givenFileinstance, with an inferred file type and no display name. - create(File, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a givenFileinstance. - create(File, String, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a givenFileinstance. - create(InputStream, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by as anInputStream. - create(InputStream, String, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by as anInputStream. - create(String, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a URL. - create(String, String, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a URL. - create(URI, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a URI. - create(URI, String, String) - Static method in class com.draftable.api.client.Comparisons.Side
-
Creates a
Comparisons.Sidefor a file provided by a URI. - createComparison(Comparisons.Side, Comparisons.Side) - Method in class com.draftable.api.client.Comparisons
-
Synchronously creates a *private* comparison that never expires with the given sides and an automatically generated identifier.
- createComparison(Comparisons.Side, Comparisons.Side, String, boolean, Instant) - Method in class com.draftable.api.client.Comparisons
-
Synchronously creates a comparison with the given sides and properties.
- createComparisonAsync(Comparisons.Side, Comparisons.Side) - Method in class com.draftable.api.client.Comparisons
-
Asynchronously creates a *private* comparison that never expires with the given sides and an automatically generated identifier.
- createComparisonAsync(Comparisons.Side, Comparisons.Side, String, boolean, Instant) - Method in class com.draftable.api.client.Comparisons
-
Asynchronously creates a comparison with the given sides and properties.
D
- defaultApiBase - Static variable in class com.draftable.api.client.Comparisons
- deleteComparison(String) - Method in class com.draftable.api.client.Comparisons
-
Synchronously deletes a given comparison.
- deleteComparisonAsync(String) - Method in class com.draftable.api.client.Comparisons
-
Asynchronously deletes a given comparison.
G
- generateIdentifier() - Static method in class com.draftable.api.client.Comparisons
- getAccountId() - Method in exception com.draftable.api.client.Comparisons.ComparisonNotFoundException
- getAllComparisons() - Method in class com.draftable.api.client.Comparisons
-
Synchronously gets a list of all of the account's comparisons.
- getAllComparisonsAsync() - Method in class com.draftable.api.client.Comparisons
-
Asynchronously gets a list of all of the account's comparisons.
- getComparison(String) - Method in class com.draftable.api.client.Comparisons
-
Synchronously gets metadata for a given comparison.
- getComparisonAsync(String) - Method in class com.draftable.api.client.Comparisons
-
Asynchronously gets metadata for a given comparison.
- getCreationTime() - Method in class com.draftable.api.client.Comparison
-
Gets when the comparison was created.
- getDisplayName() - Method in class com.draftable.api.client.Comparison.Side
-
Gets the file's display name, if one was given.
- getErrorMessage() - Method in class com.draftable.api.client.Comparison
-
If the comparison failed, gets an message describing error.
- getExpiryTime() - Method in class com.draftable.api.client.Comparison
-
Gets when the comparison expires, or null if it doesn't expire.
- getFailed() - Method in class com.draftable.api.client.Comparison
-
Gets whether the comparison failed.
- getFileType() - Method in class com.draftable.api.client.Comparison.Side
-
Gets the file's extension, as lowercase.
- getIdentifier() - Method in class com.draftable.api.client.Comparison
-
Gets the comparison's identifier.
- getIdentifier() - Method in exception com.draftable.api.client.Comparisons.ComparisonNotFoundException
- getIsPublic() - Method in class com.draftable.api.client.Comparison
-
Gets whether the comparison is public or private.
- getLeft() - Method in class com.draftable.api.client.Comparison
-
Gets metadata for the left file.
- getReady() - Method in class com.draftable.api.client.Comparison
-
Gets whether the comparison has been processed.
- getReadyTime() - Method in class com.draftable.api.client.Comparison
-
If the comparison is ready, gives the time at which processing finished.
- getRight() - Method in class com.draftable.api.client.Comparison
-
Gets metadata for the right file.
- getSourceURL() - Method in class com.draftable.api.client.Comparison.Side
-
Gets the file's source URL, if it was given by URL.
I
- InvalidAuthenticationException(String) - Constructor for exception com.draftable.api.client.Comparisons.InvalidAuthenticationException
K
- KnownURLs - Class in com.draftable.api.client
- KnownURLs() - Constructor for class com.draftable.api.client.KnownURLs
P
- publicViewerURL(String) - Method in class com.draftable.api.client.Comparisons
- publicViewerURL(String, boolean) - Method in class com.draftable.api.client.Comparisons
S
- signedViewerURL(String) - Method in class com.draftable.api.client.Comparisons
- signedViewerURL(String, Duration, boolean) - Method in class com.draftable.api.client.Comparisons
- signedViewerURL(String, Instant, boolean) - Method in class com.draftable.api.client.Comparisons
T
- toString() - Method in class com.draftable.api.client.Comparison.Side
- toString() - Method in class com.draftable.api.client.Comparison
U
- UnknownErrorException(Throwable) - Constructor for exception com.draftable.api.client.Comparisons.UnknownErrorException
All Classes All Packages