Package com.draftable.api.client
Class Comparison.Side
- java.lang.Object
-
- com.draftable.api.client.Comparison.Side
-
- Enclosing class:
- Comparison
public static final class Comparison.Side extends Object
Represents a file passed as the left or right side of a comparison.
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringgetDisplayName()Gets the file's display name, if one was given.StringgetFileType()Gets the file's extension, as lowercase.StringgetSourceURL()Gets the file's source URL, if it was given by URL.StringtoString()
-
-
-
Method Detail
-
getFileType
@Nonnull public final String getFileType()
Gets the file's extension, as lowercase.- Returns:
- The file's extension, as lowercase.
-
getSourceURL
@Nullable public final String getSourceURL()
Gets the file's source URL, if it was given by URL.- Returns:
- The source URL, if the file was given by URL, otherwise null.
-
getDisplayName
@Nullable public final String getDisplayName()
Gets the file's display name, if one was given.- Returns:
- The display name, if one was given, otherwise null.
-
-